<img src="https://files.catbox.moe/23h5zd.png" alt="chess battle advanced">

installs the `chess-battle-advanced` command-line tool when installed.  
if it doesn't work you can use the `cba` function.